@@ -105,8 +105,7 @@ class SlurmPool:
         self.nodes = {k: v for k, v in self.nodes.items() if v['free_cpus'] >= self.ncpus_per_job}
 
     def _set_max_jobs_per_node(
-        self,
-        max_jobs_per_node: Optional[int] = None,
+        self, max_jobs_per_node: Optional[int] = None,
     ):
         """Set max_jobs_per_node."""
         if self.ncpus_per_job & 0x1:
@@ -129,9 +128,7 @@ class SlurmPool:
             self.max_jobs_per_node = avail_max_jobs_per_node
 
     def _set_pool_size(
-        self,
-        max_pool_size: int,
-        pool_size: Optional[int] = None,
+        self, max_pool_size: int, pool_size: Optional[int] = None,
     ):
         """Set pool_size."""
         max_pool_size = min(sum(self.jobs_on_nodes.values()), max_pool_size)
@@ -220,7 +217,11 @@ class SlurmPool:
         ith = 0
         task_log = {}
         with Progress(
-            TextColumn("{task.description}"), BarColumn(), MofNCompleteColumn(), TimeRemainingColumn()
+            TextColumn("{task.description}"),
+            BarColumn(),
+            MofNCompleteColumn(),
+            TimeRemainingColumn(),
+            auto_refresh=False,
         ) as progress:
             for node, n_jobs in used_nodes.items():
                 logger.info(f'{node}: {n_jobs} tasks')
@@ -239,6 +240,7 @@ class SlurmPool:
                         logging_level,
                     )
                     progress.update(task, advance=1)
+                    progress.refresh()
                     ith += 1
                     task_log[task_name] = {
                         'node': node,
